@@ -1,12 +1,13 @@
 from . import resources
 from .all_components import all_components
-from .deployment import deployment
 from .get_env import get_env_util
 from .tokens import token_util
 from importlib_metadata import version
 from .django_willing_zg import django_willing_zg
 from .google_analytics import google_analytics
 from .chat import chat
+from .idle_session_handler import idle_session_handler
+from .backend_images import backend_images
 
 __all__ = [
     "all_components",
@@ -16,7 +17,9 @@ __all__ = [
     "token_util",
     "django_willing_zg",
     "google_analytics",
-    "chat"
+    "chat",
+    "idle_session_handler",
+    "backend_images",
 ]
 
 __version__ = version("willing_zg")
